Removes the cache directory used to store compiled Stan models (see poco_stan_models_cache_dir). Useful when a cached model is stale or fails to load. Mirrors sccomp::clear_stan_model_cache().

clear_stan_model_cache(cache_dir = poco_stan_models_cache_dir)

Arguments

cache_dir

Path to the cache directory to remove. Defaults to poco_stan_models_cache_dir.

Value

Invisibly NULL.

Examples

if (FALSE) { # \dontrun{
clear_stan_model_cache()
} # }