Mirrors sccomp::sccomp_stan_models_cache_dir. Used as the default cache location when poco (or downstream packages built on top of it) compile or load Stan models via cmdstanr / instantiate.

poco_stan_models_cache_dir

Format

An object of class character of length 1.

Value

A character string with the path to the cache directory.

Examples

poco_stan_models_cache_dir
#> [1] "/home/runner/.poco_models"