The compressed posterior and regenerated samples are stored in attr(x, "fit_compressed"). The original attr(x, "fit") is removed.

reconstruct_sccomp(x, n_draws = x$compressed$n_draws)

Arguments

x

The output of compress_sccomp().

n_draws

Integer number of samples to regenerate. Defaults to the number of draws stored in the compressed posterior.

Value

The sccomp object with attr(x, "fit_compressed") populated.