R/reconstruct.R
reconstruct_sccomp.RdThe compressed posterior and regenerated samples are stored in
attr(x, "fit_compressed"). The original attr(x, "fit") is removed.
reconstruct_sccomp(x, n_draws = x$compressed$n_draws)The output of compress_sccomp().
Integer number of samples to regenerate. Defaults to the number of draws stored in the compressed posterior.
The sccomp object with attr(x, "fit_compressed") populated.